chiark / gitweb /
Infrastructure: Strip away crufty CVS $Id$ tags.
[mLib] / selpk.h
diff --git a/selpk.h b/selpk.h
index 5aeed22da112ce9d5fa50b3999f955a967e455db..c43d8ada29153c3a6d490889d98384614e061de2 100644 (file)
--- a/selpk.h
+++ b/selpk.h
@@ -1,13 +1,11 @@
 /* -*-c-*-
- *
- * $Id: selpk.h,v 1.2 2000/07/16 18:56:00 mdw Exp $
  *
  * Packet-buffering select handler
  *
  * (c) 1999 Straylight/Edgeware
  */
 
-/*----- Licensing notice --------------------------------------------------* 
+/*----- Licensing notice --------------------------------------------------*
  *
  * This file is part of the mLib utilities library.
  *
  * it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
- * 
+ *
  * mLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Library General Public
  * License along with mLib; if not, write to the Free
  * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
  * MA 02111-1307, USA.
  */
 
-/*----- Revision history --------------------------------------------------* 
- *
- * $Log: selpk.h,v $
- * Revision 1.2  2000/07/16 18:56:00  mdw
- * Fix a function declaration which slipped through the net.
- *
- * Revision 1.1  2000/06/17 10:39:19  mdw
- * Experimental new support for packet buffering.
- *
- */
-
 #ifndef MLIB_SELPK_H
 #define MLIB_SELPK_H
 
@@ -105,7 +92,7 @@ extern void selpk_want(selpk */*pk*/, size_t /*sz*/);
  * Arguments:  @selpk *pk@ = pointer to buffer block
  *             @sel_state *s@ = pointer to select state to attach to
  *             @int fd@ = file descriptor to listen to
*             @void (*func)(...)@ = function to call
  *             @void *p@ = argument for function
  *
  * Returns:    ---
@@ -113,13 +100,8 @@ extern void selpk_want(selpk */*pk*/, size_t /*sz*/);
  * Use:                Initializes a buffer block.
  */
 
-extern void selpk_init(selpk */*pk*/,
-                      sel_state */*s*/,
-                      int /*fd*/,
-                      void (*/*func*/)(octet */*b*/, size_t /*sz*/,
-                                       pkbuf */*pk*/, size_t */*keep*/,
-                                       void */*p*/),
-                      void */*p*/);
+extern void selpk_init(selpk */*pk*/, sel_state */*s*/, int /*fd*/,
+                      pkbuf_func */*func*/, void */*p*/);
 
 /* --- @selpk_destroy@ --- *
  *
@@ -105,7 +92,7 @@ extern void selpk_want(selpk */*pk*/, size_t /*sz*/);
  *             @sel_state *s@ = pointer to select state to attach to
  *             @int fd@ = file descriptor to listen to
- *             @void (*func)(...)@ = function to call
+ *             @pkbuf_func *func@ = function to call
  *             @void *p@ = argument for function
  *